<?php

namespace FiloBlu\ScratchAndWin\Block\Adminhtml\ScratchAndWin\Edit\Tab;

class ScratchAndWin extends \Magento\Backend\Block\Widget\Form\Generic implements \Magento\Backend\Block\Widget\Tab\TabInterface
{
    /**
     * @var \Magento\Store\Model\System\Store
     */
    protected $_systemStore;


    /**
     * @param \Magento\Backend\Block\Template\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Data\FormFactory $formFactory
     * @param \Magento\Cms\Model\Wysiwyg\Config $wysiwygConfig
     * @param \Magento\Store\Model\System\Store $systemStore
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Template\Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Framework\Data\FormFactory $formFactory,
        \Magento\Store\Model\System\Store $systemStore,
        \Magento\Cms\Model\Wysiwyg\Config $wysiwyg,

        array $data = []
    )
    {
        $this->_systemStore = $systemStore;
        $this->_wysiwyg = $wysiwyg;

        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Init form
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setId('scratchandwin_form');
        $this->setTitle(__('ScratchAndWin Information'));
    }

    /**
     * Prepare form
     *
     * @return $this
     */
    protected function _prepareForm()
    {
        $storeId = $this->getRequest()->getParam('store',0);

        $model = $this->_coreRegistry->registry('filoblu_scratchandwin');

        $modelTranslations = $this->_coreRegistry->registry('filoblu_scratchandwin_translations');

        $form = $this->_formFactory->create();

        $form->setHtmlIdPrefix('filoblu_scratchandwin_');


        if ($storeId == 0) {

            $fieldset = $form->addFieldset(
                'base_fieldset',
                ['legend' => __('General Information'), 'class' => 'fieldset-wide']
            );

            if ($model->getId()) {
                $fieldset->addField('id', 'hidden', ['name' => 'id']);
            }

            if (!$model->getId()) {
                $model->setData('enabled', '1');
            }

            $fieldset->addField(
                'enabled',
                'select',
                [
                    'label' => __('Status'),
                    'title' => __('Status'),
                    'name' => 'enabled',
                    'required' => true,
                    'options' => ['1' => __('Enabled'), '0' => __('Disabled')]
                ]
            );

            $fieldset->addField(
                'code',
                'text',
                [
                    'name' => 'code',
                    'label' => __('Code'),
                    'title' => __('Code'),
                    'required' => true,
                    'note' => 'Used to get this item in cms block, cms pages ..'
                ]
            );
        }


        $fieldset = $form->addFieldset(
            'content_fieldset',
            ['legend' => __('Content Information'), 'class' => 'fieldset-wide']
        );

        $fieldset->addType('image', '\FiloBlu\ScratchAndWin\Block\Adminhtml\ScratchAndWin\Helper\Image');
        $fieldset->addType('file', '\FiloBlu\ScratchAndWin\Block\Adminhtml\ScratchAndWin\Helper\File');

        $fieldset->addField(
            'description',
            'editor',
            [
                'name' => 'description',
                'label' => __('Description'),
                'title' => __('Description'),
                'config' => $this->_wysiwyg->getConfig(),
                'wysiwyg' => true
            ]
        );


        $fieldset->addField(
            'bg_image',
            'image',
            array(
                'name' => 'bg_image',
                'label' => __('BG Image'),
                'title' => __('BG Image')
            )
        );

        $fieldset->addField(
            'bg_image_mobile',
            'image',
            array(
                'name' => 'bg_image_mobile',
                'label' => __('BG Image Mobile'),
                'title' => __('BG Image Mobile')
            )
        );

        $fieldset->addField(
            'bg_video',
            'file', [
                'name' => 'bg_video',
                'label' => __('BG Video'),
                'title' => __('BG Video'),
                'note' => 'Only mp4 allowed'
            ]
        );

        if ($storeId == 0) {

            $fieldset->addField(
                'custom_style',
                'textarea',
                [
                    'name' => 'custom_style',
                    'label' => __('Custom Style'),
                    'title' => __('Custom Style'),
                    'required' => false
                ]
            );
        }

        if ($storeId != 0 && $modelTranslations->getId()) {
            $unserializedValues = unserialize($modelTranslations->getSerializedValues());
            $form->setValues($unserializedValues);
        }
        else {
            $form->setValues($model->getData());
        }

//        $form->setUseContainer(true);
        $this->setForm($form);

        return parent::_prepareForm();
    }

    /**
     * Prepare label for tab
     *
     * @return string
     */
    public function getTabLabel()
    {
        return __('ScratchAndWin');
    }

    /**
     * Prepare title for tab
     *
     * @return string
     */
    public function getTabTitle()
    {
        return $this->getTabLabel();
    }

    /**
     * Can show tab in tabs
     *
     * @return boolean
     */
    public function canShowTab()
    {
        return true;
    }

    /**
     * Tab is hidden
     *
     * @return boolean
     */
    public function isHidden()
    {
        return false;
    }
}
