<?php

namespace FiloBlu\ScratchAndWin\Controller\Adminhtml\ScratchAndWinDetails;

use Magento\Backend\App\Action\Context;
use Magento\Framework\Controller\Result\JsonFactory;

/**
 * Cms page grid inline edit controller
 *
 * @SuppressWarnings(PHPMD.CouplingBetweenObjects)
 */
class InlineEdit extends \Magento\Backend\App\Action
{
    /** @var JsonFactory */
    protected $jsonFactory;
    protected $scratchAndWinDetails;

    /**
     * @param Context $context
     * @param JsonFactory $jsonFactory
     */
    public function __construct(
        Context $context,
        JsonFactory $jsonFactory,
        \FiloBlu\ScratchAndWin\Model\ScratchAndWinDetailsFactory $scratchAndWinDetails
    )
    {
        parent::__construct($context);
        $this->jsonFactory = $jsonFactory;
        $this->scratchAndWinDetails = $scratchAndWinDetails;
    }

    /**
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        /** @var \Magento\Framework\Controller\Result\Json $resultJson */
        $resultJson = $this->jsonFactory->create();
        $error = false;
        $messages = [];

        $postItems = $this->getRequest()->getParam('items', []);

        if (!($this->getRequest()->getParam('isAjax') && count($postItems))) {
            return $resultJson->setData([
                'messages' => [__('Please correct the data sent.')],
                'error' => true,
            ]);
        }

        foreach (array_keys($postItems) as $scratchandwinId) {

            $model = $this->scratchAndWinDetails->create();
            $model->load($scratchandwinId);
            $model->setData($postItems[$scratchandwinId]);

            $this->_eventManager->dispatch(
                'filoblu_scratchandwindetails_prepare_save',
                ['scratchandwindetails' => $model, 'request' => $this->getRequest()]
            );

            try {
                $model->save();
            } catch (\Magento\Framework\Exception\LocalizedException $e) {
                $messages[] = $e->getMessage();
                $error = true;
            } catch (\RuntimeException $e) {
                $messages[] = $e->getMessage();
                $error = true;
            } catch (\Exception $e) {
                $messages[] = $e->getMessage();
                $error = true;
            }
        }

        return $resultJson->setData([
            'messages' => $messages,
            'error' => $error
        ]);
    }
}
